import java.sql.Connection;
import java.sql.Date;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

import model.Student;
import utils.JDBCUtil;

public class PreparedStatementMain {

	public static void main(String[] args) {
		// testGetStuById();
		// testGetStuByName();
		// displayStudentBetweenDate("1991-10-01","1992-10-01");
	}
	
	public static void testGetStuById() {
		Scanner sc = new Scanner(System.in);
		System.out.println("Please input id:");
		long id = -1;
		while((id = sc.nextLong())!= -1) {
			Student stu = getStudentById(id);
			if (stu!=null) {
				System.out.println(stu);
			}else {
				System.out.println("未查询到!");
			}
		}
		sc.close();
		System.out.println("退出id查询");
	}
	
	public static Student getStudentById(long id){
		Connection con = null;
        PreparedStatement pStatement = null;
        ResultSet rs = null;
        String sql = "select id, stuno, name, age, gender, birthdate, major"
        		+ " from students where id like ?";
        Student stu = null;
        try {
        	con = JDBCUtil.getConnection();
        	pStatement = con.prepareStatement(sql);
        	pStatement.setLong(1, id);
        	rs = pStatement.executeQuery();
        	while(rs.next()) {
        		stu = new Student();
        		long stuid = rs.getLong(1); // 按下标取数据
        		String stuno = rs.getString("stuno"); // 按列名取
        		String strName = rs.getString(3);
        		Date date = rs.getDate("birthdate");
        		stu.setId(stuid);
        		stu.setStuno(stuno);
        		stu.setName(strName);
        		stu.setBirthdate(date.toLocalDate());
        	}
        	
		} catch (SQLException e) {
			e.printStackTrace();
		} finally {
			JDBCUtil.realeaseAll(rs, pStatement, con);
		}
        return stu;
	}
	
	public static void testGetStuByName() {
		Scanner sc = new Scanner(System.in);
		System.out.println("Please input name:");
		String name = null;
		while(!(name = sc.next()).equals("exit")) {
			List<Student> stuList = getStudentByName("%"+name+"%");
			if (stuList.size()!=0) {
				for (var student : stuList) {
					System.out.println(student);
				}
			}else {
				System.out.println("未查询到!");
			}
		}
		sc.close();
		System.out.println("退出name查询");
	}
	
	public static List<Student> getStudentByName(String name){
		Connection con = null;
        PreparedStatement pStatement = null;
        ResultSet rs = null;
        String sql = "select id, stuno, name, age, gender, birthdate, major"
        		+ " from students where name like ?";
        Student stu = null;
        List<Student> stuList = new ArrayList<>();
        try {
        	con = JDBCUtil.getConnection();
        	pStatement = con.prepareStatement(sql);
        	pStatement.setString(1, name);
        	rs = pStatement.executeQuery();
        	while(rs.next()) {
        		stu = new Student();
        		long stuid = rs.getLong(1); // 按下标取数据
        		String stuno = rs.getString("stuno"); // 按列名取
        		String strName = rs.getString(3);
        		Date date = rs.getDate("birthdate");
        		stu.setId(stuid);
        		stu.setStuno(stuno);
        		stu.setName(strName);
        		stu.setBirthdate(date.toLocalDate());
        		stuList.add(stu);
        	}
		} catch (SQLException e) {
			e.printStackTrace();
		} finally {
			JDBCUtil.realeaseAll(rs, pStatement, con);
		}
        return stuList;
	}
	
	public static void displayStudentBetweenDate(String begin,String end) {
		Connection con = null;
        PreparedStatement pStatement = null;
        ResultSet rs = null;
        String sql = "select * from students where birthdate between ? and ?";
        Student stu = null;
        try {
        	con = JDBCUtil.getConnection();
        	pStatement = con.prepareStatement(sql);
        	pStatement.setString(1, begin); // 对日期类型依然可以出传递String类型参数
        	pStatement.setString(2, end);
        	rs = pStatement.executeQuery();
        	while(rs.next()) {
        		stu = new Student();
        		long stuid = rs.getLong(1); // 按下标取数据
        		String stuno = rs.getString("stuno"); // 按列名取
        		String strName = rs.getString(3);
        		Date date = rs.getDate("birthdate");
        		stu.setId(stuid);
        		stu.setStuno(stuno);
        		stu.setName(strName);
        		stu.setBirthdate(date.toLocalDate());
        		System.out.println(stu);
        	}
        	
		} catch (SQLException e) {
			e.printStackTrace();
		} finally {
			JDBCUtil.realeaseAll(rs, pStatement, con);
		}
	}

}
